# Synchronization Logging
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/synchronization-logging#overview)
  * [Synchronization Runs](https://help.sap.com/docs/leanix/ea/synchronization-logging#synchronization-runs)
  * [Logging Details](https://help.sap.com/docs/leanix/ea/synchronization-logging#logging-details)
  * [Why Synchronizations Fail](https://help.sap.com/docs/leanix/ea/synchronization-logging#why-synchronizations-fail)
  * [Initiating a Synchronization Run Manually](https://help.sap.com/docs/leanix/ea/synchronization-logging#initiating-a-synchronization-run-manually)
  * [Troubleshooting Synchronization Issues](https://help.sap.com/docs/leanix/ea/synchronization-logging#troubleshooting-synchronization-issues)


Use synchronization logs to track the state of your integrations.
